@@ -1,18 +1,23 @@
 import mysql.connector
 import cx_Oracle
 from src.database.utils import DatabaseConfig
+import src
 
 
 class Connection:
     def __init__(self, db_config: DatabaseConfig):
         self.db_type = db_config.db_type.lower()
+        self.db_config = db_config
         if self.db_type == 'mysql':
             self.conn = get_mysql_connection(db_config.db_host, db_config.db_name, db_config.db_user, db_config.db_pwd)
         elif self.db_type == 'oracle':
-            self.conn = get_oracle_client_connection(db_config.db_host, db_config.db_user, db_config.db_pwd, db_config.db_client)
+            self.conn = get_oracle_client_connection(db_config.db_client, db_config.db_user, db_config.db_pwd, db_config.db_host)
 
     def get_conect(self):
-        return self.conn
+        if self.db_type == 'oracle':
+            return get_oracle_connection(self.db_config.db_host, self.db_config.db_user, self.db_config.db_pwd)
+        else:
+            return self.conn
 
 
 def get_mysql_connection(db_host: str, db_name: str, db_user: str, db_pwd):
@@ -29,9 +34,9 @@ def get_oracle_connection(db_host: str, db_user: str, db_pwd):
 
 
 def get_oracle_client_connection(db_client: str, db_user: str, db_pwd: str, db_host: str):
-    if globals()['is_connected_oracle_client'] is False:
+    if src.is_connected_oracle_client is False:
         cx_Oracle.init_oracle_client(lib_dir=rf'{db_client}')
-        globals()['is_connected_oracle_client'] = True
+        src.is_connected_oracle_client = True
 
     return cx_Oracle.connect(user=db_user,
                              password=db_pwd,
