@@ -11,20 +11,21 @@ class Pedido:
 
     def __init__(self, id, pedido_venda_id, data_pedido, data_geracao,
                  codigo_referencia, valor_total, valor_forma_pagamento,
-                 valor_desconto, valor_frete, status, quantidade_titulos,
+                 valor_desconto, valor_frete, status: str, quantidade_titulos,
                  previsao_entrega, codigo_rastreio, canal_id,
                  transportadora_id, transportadora,
                  servico_id, servico, codigo_carga,
-                 transacao, usuario, pagamento,
+                 transacao, usuario, pagamento: list[Pagamento],
                  itens, itens_brinde, itens_personalizados,
                  forma_pagamento_parceiro, forma_envio_parceiro,
-                 pedido_nota_fiscal, protocolo):
+                 pedido_nota_fiscal, protocolo, valor_adicional_forma_pagamento):
         self.id = id
         self.pedido_venda_id = pedido_venda_id
         self.data_pedido = data_pedido
         self.data_geracao = data_geracao
         self.codigo_referencia = codigo_referencia
         self.valor_total = valor_total
+        self.valor_adicional_forma_pagamento = valor_adicional_forma_pagamento
         self.valor_forma_pagamento = valor_forma_pagamento
         self.valor_desconto = valor_desconto
         self.valor_frete = valor_frete
@@ -60,8 +61,7 @@ class Pedido:
         self.itens = []
         if itens is not None:
             for item in itens:
-                p = Product(**item)
-                self.itens.append(p)
+                self.itens.append(OrderItem(**item))
 
         self.itens_brinde: List[ItemBrinde]
         self.itens_brinde = []
@@ -208,6 +208,9 @@ class Pedido:
         return sql
 
 
+
+
+
 class Transacao:
 
     def __init__(self, transacao_id, numero_autorizacao,
@@ -255,7 +258,6 @@ class NotaFiscal:
 
 
 class Fila:
-
     def __init__(self, pedido_id, data_pedido,
                  status, protocolo, data_fila,
                  observacao, valor_total):
@@ -268,10 +270,10 @@ class Fila:
         self.valor_total = valor_total
 
 
-def toListFilaDecoder(filaDictArray):
+def toListFilaDecoder(fila):
     lista = []
-    for fila in filaDictArray:
-        lista.append(Fila(**fila))
+    for item in fila:
+        lista.append(Fila(**item))
 
     return lista
 
