@@ -10,8 +10,8 @@ class CatalogoResponse:
 
 
 class PriceResponse:
-    def __init__(self, Identifiers: list[str], Status: int, Message: str, Protocolo: str):
-        self.identifiers = Identifiers
+    def __init__(self, codigo_erp, Status: int, Message: str, Protocolo: str):
+        self.codigo_erp = codigo_erp
         self.status = Status
         self.message = Message
         self.protocolo = Protocolo
