@@ -51,12 +51,14 @@ def job_send_prices(job_config_dict: dict):
         prices_to_protocol = []
         prices = query_prices(db_config)
         if len(prices) > 0:
-            price_response = api_okvendas.post_prices(src.client_data.get('url_api') + '/catalogo/precos', prices, src.client_data.get('token_api'))
-            for res in price_response:
-                if res.status == 1:
-                    prices_to_protocol.append(res.identifiers[0])
+            logger.info(job_config_dict.get('job_name') + f' | Produtos para atualizar preco {len(prices)}')
+
+            for price in prices:
+                response = api_okvendas.post_prices(src.client_data.get('url_api') + '/catalogo/preco', price, src.client_data.get('token_api'))
+                if response.status == 1:
+                    prices_to_protocol.append(response.codigo_erp)
                 else:
-                    logger.warning(job_config_dict.get('job_name') + f' | Nao foi possivel atualizar o preco do sku {res.identifiers[0]}. Erro recebido da Api: {res.message}')
+                    logger.warning(job_config_dict.get('job_name') + f' | Nao foi possivel atualizar o preco do sku {response.codigo_erp}. Erro recebido da Api: {response.message}')
 
             protocol_prices(db_config, prices_to_protocol)
 
