@@ -46,39 +46,35 @@ def job_send_stocks(job_config_dict: dict):
     db_config = utils.get_database_config(job_config_dict)
     stocks = query_stocks(db_config)
     p_size = len(stocks) if stocks is not None else 0
-
+    atualizados = []
     if p_size > 0:
         logger.debug("Total de produtos atualiza estoque API: {}".format(p_size))
-        jsn_prods = api_okvendas.send_stocks(src.client_data.get('url_api') + '/catalogo/estoques', stocks, src.client_data.get('token_api'))
+        for stock in stocks:
+            response, status_code = api_okvendas.send_stocks(src.client_data.get('url_api') + '/catalogo/estoque', stock, src.client_data.get('token_api'))
 
-        atualizados = []
-        mensagens = []
+            if response is not None:
+                logger.debug('Atualizando produtos no semaforo')
+                conexao = database.Connection(db_config)
+                conn = conexao.get_conect()
+                cursor = conn.cursor()
 
-        if jsn_prods is not None:
-            logger.debug('Atualizando produtos no semaforo')
-            conexao = database.Connection(db_config)
-            conn = conexao.get_conect()
-            cursor = conn.cursor()
-
-            # Identifiers, Status, Message, Protocolo
-            for p in jsn_prods:
-                if p['Status'] == 1:
-                    cod_erp = p['Identifiers'][0]
+                codigo_erp = response['codigo_erp']
+                if response['Status'] == 1 or response['Status'] == 'Success':
                     try:
                         sql_protocolar_estoque = queries.get_stock_protocol_command(db_config.db_type)
-                        cursor.execute(sql_protocolar_estoque, queries.get_command_parameter(db_config.db_type, [cod_erp]))
-                        atualizados.append(cod_erp)
+                        cursor.execute(sql_protocolar_estoque, queries.get_command_parameter(db_config.db_type, [codigo_erp]))
+                        atualizados.append(response['codigo_erp'])
                     except Exception as ex:
                         logger.error(str(ex), exc_info=True)
                 else:
-                    mensagens.append(p['Message'])
+                    logger.warning(job_config_dict.get('job_name') + f' | Erro ao atualizar estoque para o sku {codigo_erp}: {response["Message"]}')
 
-            cursor.close()
-            conn.commit()
-            conn.close()
+                cursor.close()
+                conn.commit()
+                conn.close()
 
-            total = len(atualizados)
-            logger.debug('Atualizado produtos no semaforo: {}'.format(total))
+        total = len(atualizados)
+        logger.debug('Atualizado estoques no semaforo: {}'.format(total))
     else:
         logger.warning("Nao ha produtos para atualizar estoque")
 
@@ -204,8 +200,8 @@ def stock_dict(produtos):
     lista = []
     for row in produtos:
         pdict = {
-            'codigo_erp': row[1],
-            'quantidade': int(row[2])
+            'codigo_erp': row['CODIGO_ERP'],
+            'quantidade': int(row['QUANTIDADE'])
         }
         lista.append(pdict)
 
